@@ -17,10 +17,9 @@ class PersonModelViewSet(ModelViewSet):
                 'name_prefix'
             ),
             Row(
-                'name_prefix',
-                'first_name',
+                'last_name',
                 'middle_name',
-                'last_name'
+                'first_name',
             ),
         ),
         Fieldset(
